encryption_property = {
    'aws_db_instance': 'storage_encrypted',
    'ebs_block_device': 'encrypted',
    'aws_ebs_volume': 'encrypted',
    'azurerm_storage_account': 'enable_blob_encryption',
    'azurerm_sql_database': 'encryption',
    'aws_s3_bucket': 'server_side_encryption_configuration',
    'aws_elasticache_replication_group': 'at_rest_encryption_enabled'
}

resource_name = {
    'AWS Auto-Scaling Group': 'aws_autoscaling_group',
    'AWS EBS volume': 'aws_ebs_volume',
    'AWS EC2 instance': 'aws_instance',
    'AWS EFS file system': 'aws_efs_file_system',
    'AWS ELB resource': 'aws_elb',
    'AWS Internet Gateway': 'aws_internet_gateway',
    'AWS Launch Configuration': 'aws_launch_configuration',
    'AWS RDS instance': 'aws_db_instance',
    'AWS Route Table': 'aws_route_table',
    'AWS S3 Bucket': 'aws_s3_bucket',
    'AWS Security Group': 'aws_security_group',
    'AWS VPC': 'aws_vpc',
    'Azure SQL Database': 'azurerm_sql_database',
    'Azure Storage Account': 'azurerm_storage_account',
    'AWS Subnet': 'aws_subnet'
}



import os
import sys
import subprocess


def which(program):
    def is_exe(fpath):
        return os.path.isfile(fpath) and os.access(fpath, os.X_OK)

    fpath, fname = os.path.split(program)
    if fpath:
        if is_exe(program):
            return program
    else:
        for path in os.environ["PATH"].split(os.pathsep):
            exe_file = os.path.join(path, program)
            if is_exe(exe_file):
                return exe_file
    return None


def convert_terraform_plan_to_json(terraform_plan_file, terraform_executable=None):
    print('. Converting terraform plan file.')
    if terraform_executable is None:
        terraform_executable = which('terraform')

    path = os.path.dirname(terraform_plan_file)

    cwd = os.getcwd()
    os.chdir(path)
    with open('{}.json'.format(terraform_plan_file), 'w') as FP_plan_file:
        terraform = subprocess.run([terraform_executable, 'show', '-json', terraform_plan_file],
                                   universal_newlines=True,
                                   stdout=FP_plan_file,
                                   stderr=subprocess.PIPE)

    os.chdir(cwd)

    if terraform.returncode == 0:
        return '{}.json'.format(terraform_plan_file)

    print('ERROR: Failed to convert terraform plan file to JSON format via terraform. Here is the error :')
    print(terraform.stdout)
    print(terraform.stderr)
    sys.exit(1)
